@@ -27,6 +27,72 @@ if sys.platform == 'win32':
 # Create console with Windows encoding handling
 console = Console()
 
+
+def _has_npm_available() -> bool:
+    """
+    Check if npm is available (handles Windows PATH refresh issues)
+
+    On Windows, npm might be installed but not yet in PATH for the current session.
+    This checks multiple sources to detect npm reliably.
+    """
+    # Quick check: is npm in PATH?
+    if shutil.which('npm'):
+        return True
+
+    # Windows: Try running npm directly (might work even if not in current PATH)
+    import subprocess
+    import platform
+    if platform.system() == 'Windows':
+        try:
+            result = subprocess.run(['npm', '--version'], capture_output=True, timeout=5)
+            if result.returncode == 0:
+                return True
+        except:
+            pass
+
+        # Check common Windows install locations
+        common_paths = [
+            Path(r'C:\Program Files\nodejs\npm.cmd'),
+            Path(r'C:\Program Files (x86)\nodejs\npm.cmd'),
+        ]
+        for path in common_paths:
+            if path.exists():
+                return True
+
+    return False
+
+
+def _has_pip_available() -> bool:
+    """
+    Check if pip is available (handles Windows PATH refresh issues)
+
+    On Windows, pip is always available via 'py -m pip' even if not in PATH.
+    """
+    # Quick check: is pip in PATH?
+    if shutil.which('pip') or shutil.which('pip3'):
+        return True
+
+    # Windows: Python's pip is always available via 'py -m pip'
+    import subprocess
+    import platform
+    if platform.system() == 'Windows':
+        try:
+            result = subprocess.run(['py', '-m', 'pip', '--version'], capture_output=True, timeout=5)
+            return result.returncode == 0
+        except:
+            pass
+
+    # Unix: Try python3 -m pip
+    try:
+        import subprocess
+        result = subprocess.run(['python3', '-m', 'pip', '--version'], capture_output=True, timeout=5)
+        return result.returncode == 0
+    except:
+        pass
+
+    return False
+
+
 # Monkey-patch console.print to handle Windows encoding issues
 _original_print = console.print
 
@@ -233,8 +299,9 @@ def _install_tools(tools: list, use_latest: bool = False):
         }
         installer = installer_map.get(pm)
 
-    npm_installer = NpmInstaller() if shutil.which('npm') else None
-    pip_installer = PipInstaller() if shutil.which('pip') or shutil.which('pip3') else None
+    # Smart installer detection (Windows PATH refresh workaround)
+    npm_installer = NpmInstaller() if _has_npm_available() else None
+    pip_installer = PipInstaller() if _has_pip_available() else None
 
     installed = 0
     failed = 0
@@ -286,6 +353,10 @@ def _install_tools(tools: list, use_latest: bool = False):
 
         if success:
             installed += 1
+            # Mark tool as installed in cache (prevents reinstall prompts on Windows)
+            from medusa.platform.tool_cache import ToolCache
+            cache = ToolCache()
+            cache.mark_installed(tool)
         else:
             console.print(f"  [red]❌ Failed[/red] (tried: {', '.join(attempted_installers) if attempted_installers else 'no installers available'})")
             failed += 1
@@ -421,6 +492,10 @@ def _install_tools(tools: list, use_latest: bool = False):
                             if npm_installer.install(tool, use_latest=use_latest):
                                 console.print(f"  [green]✅ Installed via npm[/green]\n")
                                 npm_installed += 1
+                                # Mark tool as installed in cache
+                                from medusa.platform.tool_cache import ToolCache
+                                cache = ToolCache()
+                                cache.mark_installed(tool)
                             else:
                                 console.print(f"  [red]❌ Failed[/red]\n")
 
@@ -910,8 +985,8 @@ def install(tool, check, all, yes, use_latest):
         installer = installer_map.get(pm)
 
     # Also check for cross-platform installers
-    npm_installer = NpmInstaller() if shutil.which('npm') else None
-    pip_installer = PipInstaller() if shutil.which('pip') else None
+    npm_installer = NpmInstaller() if _has_npm_available() else None
+    pip_installer = PipInstaller() if _has_pip_available() else None
 
     # Install specific tool
     if tool:
@@ -979,31 +1054,62 @@ def install(tool, check, all, yes, use_latest):
         console.print()
         installed = 0
         failed = 0
+        failed_details = []  # Track why each tool failed
 
         for tool_name in missing_tools:
-            console.print(f"[cyan]Installing {tool_name}...[/cyan]", end=" ")
+            console.print(f"[cyan]Installing {tool_name}...[/cyan]")
 
             # Determine best installer
             success = False
+            tried = []
 
             # Try system package manager first
-            if installer and ToolMapper.get_package_name(tool_name, pm.value if pm else ''):
+            pm_package = ToolMapper.get_package_name(tool_name, pm.value if pm else '') if pm else None
+            if installer and pm_package:
+                console.print(f"  → Trying {pm.value}: {pm_package}")
+                tried.append(pm.value)
                 success = installer.install(tool_name)
+                if success:
+                    console.print(f"  [green]✅ Installed via {pm.value}[/green]\n")
+            elif pm:
+                console.print(f"  ⊘ Not available in {pm.value}")
 
-            # Try npm
-            if not success and npm_installer and ToolMapper.get_package_name(tool_name, 'npm'):
-                success = npm_installer.install(tool_name, use_latest=use_latest)
+            # Try npm for npm tools
+            if not success and ToolMapper.is_npm_tool(tool_name):
+                npm_package = ToolMapper.get_package_name(tool_name, 'npm')
+                if npm_installer and npm_package:
+                    console.print(f"  → Trying npm: {npm_package}")
+                    tried.append('npm')
+                    success = npm_installer.install(tool_name, use_latest=use_latest)
+                    if success:
+                        console.print(f"  [green]✅ Installed via npm[/green]\n")
+                else:
+                    console.print(f"  ⊘ npm not available")
+                    tried.append('npm (not available)')
 
-            # Try pip
-            if not success and pip_installer and ToolMapper.get_package_name(tool_name, 'pip'):
-                success = pip_installer.install(tool_name, use_latest=use_latest)
+            # Try pip for python tools
+            if not success and ToolMapper.is_python_tool(tool_name):
+                pip_package = ToolMapper.get_package_name(tool_name, 'pip')
+                if pip_installer and pip_package:
+                    console.print(f"  → Trying pip: {pip_package}")
+                    tried.append('pip')
+                    success = pip_installer.install(tool_name, use_latest=use_latest)
+                    if success:
+                        console.print(f"  [green]✅ Installed via pip[/green]\n")
+                else:
+                    console.print(f"  ⊘ pip not available")
+                    tried.append('pip (not available)')
 
             if success:
-                console.print("[green]✅[/green]")
                 installed += 1
+                # Mark as installed in cache
+                from medusa.platform.tool_cache import ToolCache
+                cache = ToolCache()
+                cache.mark_installed(tool_name)
             else:
-                console.print("[red]❌[/red]")
+                console.print(f"  [red]❌ Failed[/red] (tried: {', '.join(tried) if tried else 'no installers'})\n")
                 failed += 1
+                failed_details.append((tool_name, ', '.join(tried) if tried else 'no installers'))
 
         console.print()
         console.print(f"[bold]Installation Summary:[/bold]")
@@ -1079,8 +1185,8 @@ def uninstall(tool, all, yes):
             }
             installer = installer_map.get(pm)
 
-        npm_installer = NpmInstaller() if shutil.which('npm') else None
-        pip_installer = PipInstaller() if shutil.which('pip') else None
+        npm_installer = NpmInstaller() if _has_npm_available() else None
+        pip_installer = PipInstaller() if _has_pip_available() else None
 
         success = False
 
@@ -1126,8 +1232,8 @@ def uninstall(tool, all, yes):
             }
             installer = installer_map.get(pm)
 
-        npm_installer = NpmInstaller() if shutil.which('npm') else None
-        pip_installer = PipInstaller() if shutil.which('pip') else None
+        npm_installer = NpmInstaller() if _has_npm_available() else None
+        pip_installer = PipInstaller() if _has_pip_available() else None
 
         uninstalled = 0
         failed = 0
